Class: TsonRails::Absent

Inherits:
Object
  • Object
show all
Defined in:
lib/tson_rails/absent.rb

Overview

A value that is present in a container but intentionally has no value. This is distinct from nil, which is encoded as the TSON null value.

Instance Method Summary collapse

Instance Method Details

#inspectObject Also known as: to_s



7
8
9
# File 'lib/tson_rails/absent.rb', line 7

def inspect
  "TsonRails.absent"
end