Class: TsonRails::Absent
- Inherits:
-
Object
- Object
- TsonRails::Absent
- Defined in:
- lib/tson_rails/absent.rb
Overview
A value that is present in a container but intentionally has no value. This is distinct from nil, which is encoded as the TSON null value.
Instance Method Summary collapse
- #inspect ⇒ Object (also: #to_s)
Instance Method Details
#inspect ⇒ Object Also known as: to_s
7 8 9 |
# File 'lib/tson_rails/absent.rb', line 7 def inspect "TsonRails.absent" end |